;; adds mode highlighting for emacs/xemacs 
(add-to-list 'auto-mode-alist '("\\.zpt$" . html-mode))
(add-to-list 'auto-mode-alist '("\\.dtml$" . html-mode))
(add-to-list 'auto-mode-alist '("\\.zsql$" . sql-mode))
;; directory views now have python suffixes with .py
;;(add-to-list 'auto-mode-alist '("\\.ps$" . python-mode))
